function AMFMexamples
%
% Three examples using DESA algorithm for AM and/or FM decomposition.
%
% (c) Yannis Pantazis, 2007, csd, uoc
%     mail: pantazis@csd.uoc.gr

A = 3;
a = 1/500;

fs = 10000;
n = 1:fs/20;

Wo = 2*pi*1000/fs;
Wm = 2*pi*80/fs;
b = .4*Wo/Wm;

%Apply Teager Energy Operator
x = A*exp(-a*n) .* cos(Wo*n + b*sin(Wm*n));
subplot(211);plot(x(2:end-1));xlabel('samples');ylabel('signal');
subplot(212);hold on;plot(A*exp(-a*n(2:end-1)).*sin(Wo+b*Wm*cos(Wm*n(2:end-1))),'g');
plot(sqrt(Teager(x)),'--');hold off;xlabel('samples');ylabel('energy');legend('energy','Teager');

%Apply DESA on a AM signal
x = A*exp(-a*n) .* cos(Wo*n);
subplot(311);plot(x);xlabel('samples');ylabel('signal');
[AMx FMx] = DESA(x, Wo);
subplot(312);plot(A*exp(-a*n),'g');hold on;plot(AMx/8,'--');hold off;xlabel('samples');ylabel('AM component');legend('original','DESA');
subplot(313);plot([1 500],fs*[Wo Wo]/(2*pi),'g');hold on;plot((fs*FMx/(2*pi)),'--');hold off;axis([0 500 800 1200]);xlabel('samples');ylabel('FM component');legend('original','DESA');

%Apply DESA on a FM signal
x = cos(Wo*n + b*sin(Wm*n));
subplot(311);plot(x);
[AMx FMx] = DESA(x, Wo);
subplot(312);plot(ones(size(AMx)),'g');hold on;plot(AMx/8,'--');hold off;xlabel('samples');ylabel('AM component');legend('original','DESA');
subplot(313);plot(fs*(Wo+b*Wm*cos(Wm*n))/(2*pi),'g');hold on;plot(fs*FMx/(2*pi),'--');hold off;xlabel('samples');ylabel('FM component');legend('original','DESA');

%Apply DESA on a AM&FM signal
x = A*exp(-a*n) .* cos(Wo*n + b*sin(Wm*n));
subplot(311);plot(x);
[AMx FMx] = DESA(x, Wo);
subplot(312);plot(A*exp(-a*n),'g');hold on;plot(AMx/8,'--');hold off;xlabel('samples');ylabel('AM component');legend('original','DESA');
subplot(313);plot(fs*(Wo+b*Wm*cos(Wm*n))/(2*pi),'g');hold on;plot(fs*FMx/(2*pi),'--');hold off;xlabel('samples');ylabel('FM component');legend('original','DESA');

